Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/videolan/dav1d.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/src/arm/64
diff options
context:
space:
mode:
authorMartin Storsjö <martin@martin.st>2020-02-18 01:13:43 +0300
committerJean-Baptiste Kempf <jb@videolan.org>2020-03-02 12:58:11 +0300
commitebbf91f44422c7a2778a9e524a9cc7a1b5c66dcf (patch)
tree1f91b2e96ef1d8c3170f2e514515dfa95ecc6e12 /src/arm/64
parentac492552babb8c7916a9347768f4dcacbb47dd42 (diff)
arm: loopfilter: Prepare for 16 bpc
Diffstat (limited to 'src/arm/64')
-rw-r--r--src/arm/64/loopfilter.S10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/arm/64/loopfilter.S b/src/arm/64/loopfilter.S
index af9dfe6..d45f208 100644
--- a/src/arm/64/loopfilter.S
+++ b/src/arm/64/loopfilter.S
@@ -981,13 +981,13 @@ function lpf_h_16_16_neon
br x15
endfunc
// void dav1d_lpf_v_sb_y_neon(pixel *dst, const ptrdiff_t stride,
// const uint32_t *const vmask,
// const uint8_t (*l)[4], ptrdiff_t b4_stride,
// const Av1FilterLUT *lut, const int w)
.macro lpf_func dir, type
-function lpf_\dir\()_sb_\type\()_neon, export=1
+function lpf_\dir\()_sb_\type\()_8bpc_neon, export=1
mov x11, x30
stp d8, d9, [sp, #-0x40]!
stp d10, d11, [sp, #0x10]
@@ -981,13 +981,13 @@ function lpf_h_16_16_neon
br x15
endfunc
-// void dav1d_lpf_v_sb_y_neon(pixel *dst, const ptrdiff_t stride,
-// const uint32_t *const vmask,
-// const uint8_t (*l)[4], ptrdiff_t b4_stride,
-// const Av1FilterLUT *lut, const int w)
+// void dav1d_lpf_v_sb_y_8bpc_neon(pixel *dst, const ptrdiff_t stride,
+// const uint32_t *const vmask,
+// const uint8_t (*l)[4], ptrdiff_t b4_stride,
+// const Av1FilterLUT *lut, const int w)
.macro lpf_func dir, type